@@ -241,13 +241,13 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
             alternatives = []
         else:
             alternatives = json.loads(row["alternatives"])
+            if isinstance(alternatives, list) and isinstance(alternatives[0], dict):
+                alternatives = [alternatives]
 
-        if isinstance(alternatives, list) and isinstance(alternatives[0], dict):
-            alternatives = [alternatives]
         dataset.append({
             "priority": 1,
             "data_source": "fsm",
-            "data_id": row["data_id"],
+            "data_id": row["conversation_uuid"],
             "data": {
                 "call_uuid": row["call_uuid"],
                 "conversation_uuid": row["conversation_uuid"],
